Learn R Programming

compicc (version 0.1.0)

indep_ci: Confidence Interval for the difference between two independent ICCs

Description

Confidence Interval for the difference between two independent ICCs

Usage

indep_ci(data1, data2, conf_level = 0.95)

Arguments

data1

A dataframe in wide format

data2

A dataframe in wide format

conf_level

The confidence level of the confidence interval; defaults to 0.95 (95%).

Value

A list with 3 elements:

ICC of data1 ($icc_1)

ICC of data2 ($icc_2)

Confidence interval for the difference between the ICC of data1 and the ICC of data2 ($confidenceIntervalDifference)

The confidence interval is a 1x2 dataframe with calls $lowerBound and $upperBound for the bounds of the interval

Details

Used when a different set of subjects are tested in each dataframe. The wide format for the dataframe means that the subjects constitute the rows, and the multiple trials per subject constitute the columns of the dataframe.

Examples

Run this code
# NOT RUN {
subject1_test1 <- c(46, 42, 43)
subject2_test1 <- c(34, 35, 34)
subject3_test1 <- c(51, 48, 54)
rater1Data <- data.frame(subject1_test1, subject2_test1, subject3_test1)

subject4_test2 <- c(26, 25, 28)
subject5_test2 <- c(43, 45, 45)
subject6_test2 <- c(30, 31, 31)
rater2Data <- data.frame(subject4_test2, subject5_test2, subject6_test2)

indep_ci(rater1Data, rater2Data)
indep_ci(rater1Data, rater2Data, conf_level = 0.90)

# }

Run the code above in your browser using DataLab